public final class GenomeVariant extends Object implements VariantDescription
getType() etc. do not return
sensible results.| Constructor and Description |
|---|
GenomeVariant(GenomePosition pos,
String ref,
String alt)
Construct object given the position, reference, and alternative nucleic acid string.
|
GenomeVariant(GenomePosition pos,
String ref,
String alt,
Strand strand)
Construct object given the position, reference, alternative nucleic acid string, and strand.
|
GenomeVariant(GenomeVariant other,
Strand strand)
Construct object and enforce strand.
|
| Modifier and Type | Method and Description |
|---|---|
int |
compareTo(Annotation other) |
boolean |
equals(Object obj) |
String |
getAlt() |
int |
getChr() |
String |
getChrName() |
GenomeInterval |
getGenomeInterval() |
GenomePosition |
getGenomePos() |
int |
getPos() |
String |
getRef() |
GenomeVariantType |
getType() |
int |
hashCode() |
boolean |
isSymbolic() |
boolean |
isTransition()
A transition is between purine and purine or between pyrimidine and pyrimidine.
|
boolean |
isTransversion()
A transversion is purine <-> pyrimidine.
|
String |
toString() |
GenomeVariant |
withStrand(Strand strand) |
public GenomeVariant(GenomePosition pos, String ref, String alt)
public GenomeVariant(GenomePosition pos, String ref, String alt, Strand strand)
public GenomeVariant(GenomeVariant other, Strand strand)
public boolean isSymbolic()
true if this is a symbolic allele, as describedpublic String getChrName()
getChrName in interface VariantDescriptionpublic GenomePosition getGenomePos()
public int getPos()
getPos in interface VariantDescriptionpublic String getRef()
getRef in interface VariantDescriptionpublic String getAlt()
getAlt in interface VariantDescriptionpublic int getChr()
getChr in interface VariantDescriptionpublic GenomeInterval getGenomeInterval()
public GenomeVariant withStrand(Strand strand)
public String toString()
public GenomeVariantType getType()
GenomeVariantType of this GenomeChangepublic boolean isTransition()
public boolean isTransversion()
public int compareTo(Annotation other)
compareTo in interface VariantDescriptionCopyright © 2016. All rights reserved.